aboutsummaryrefslogtreecommitdiff
path: root/runtime/indent/javascriptreact.vim
diff options
context:
space:
mode:
authorDavid Balatero <dbalatero@gmail.com>2026-05-04 12:10:45 -0400
committerGitHub <noreply@github.com>2026-05-04 12:10:45 -0400
commitcbedd537ac8542a7c4b6b4463e137a764277a5a3 (patch)
treea2bb372c83b7ca53734cf7f577925c8f451aebfe /runtime/indent/javascriptreact.vim
parent7fff439395215001ab74a96cc3df3d1b6d795177 (diff)
downloadrneovim-cbedd537ac8542a7c4b6b4463e137a764277a5a3.tar.gz
rneovim-cbedd537ac8542a7c4b6b4463e137a764277a5a3.tar.bz2
rneovim-cbedd537ac8542a7c4b6b4463e137a764277a5a3.zip
fix(ci): generate more data to stress output throttling test #39577
Problem: This test would sometimes fail to match lines starting with `.` (indicating throttling) due to a race condition, likely because throttling completed before the test could properly assert. Solution: I 6x'd the amount of test data we were pushing into `nvim` in an attempt to trigger throttling consistently. I don't _love_ this solution as it is still non-deterministic and might not hold up over time. A good solution would be: create a deterministic way to pause neovim in a functional test, assert on the temporarily throttle state, then unpause neovim. However, it's likely this is not possible today and will take too much effort. Before test time (30000 lines): ~0.40sec/run After test time (150000 lines): ~1.7sec/run This increases test runtime, but if it removes flakes I think it's worth it.
Diffstat (limited to 'runtime/indent/javascriptreact.vim')
0 files changed, 0 insertions, 0 deletions